var env = 'production';
// var env = 'development';

var gulp = require('gulp');

// Define Sass and the autoprefixer
var sass = require('gulp-sass');
var prefix = require('gulp-autoprefixer');
var sassGlob = require('gulp-sass-glob');
var sourcemaps = require('gulp-sourcemaps');
var concat = require('gulp-concat');
var rename = require('gulp-rename');
var uglify = require('gulp-uglify');
var notify = require('gulp-notify');

// This is an object which defines paths for the styles.
// Can add paths for javascript or images for example
// The folder, files to look for and destination are all required for sass
var paths = {
  styles: {
    src: 'src/sass',
    files: 'src/sass/**/*.scss',
    dest: 'css'
  },
  scripts: {
    src: 'src/js',
    files: ['src/js/**/*.js', '!src/js/vendor/**/*.js'],
    dest: 'js'
  },
  vendorscripts: {
    src: 'src/js/vendor',
    files: ['src/js/vendor/**/*.js', '!src/js/vendor/**/*.min.js'],
    dest: 'js'
  }
}

// A display error function, to format and make custom errors more uniform
// Could be combined with gulp-util or npm colors for nicer output
var displayError = function(error) {
  // Initial building up of the error
  var errorString = '[' + error.plugin + ']';
  errorString += ' ' + error.message.replace("\n",''); // Removes new line at the end
  // If the error contains the filename or line number add it to the string
  if (error.fileName)
    errorString += ' in ' + error.fileName;
  if (error.lineNumber)
    errorString += ' on line ' + error.lineNumber;
  // This will output an error like the following:
  // [gulp-sass] error message in file_name on line 1
  console.error(errorString);
}

gulp.task('vendorscripts', function() {

  return gulp.src(paths.vendorscripts.files)
    .pipe(concat('vendor.js'))
    .pipe(gulp.dest(paths.vendorscripts.dest))
    .pipe(rename({suffix: '.min'}))
    .pipe(uglify())
    .pipe(gulp.dest(paths.vendorscripts.dest))
    .pipe(notify({ message: 'Scripts task complete' }));

});

gulp.task('scripts', function() {

  return gulp.src(paths.scripts.files)
    .pipe(concat('site.js'))
    .pipe(gulp.dest(paths.scripts.dest))
    .pipe(rename({suffix: '.min'}))
    .pipe(uglify())
    .pipe(gulp.dest(paths.scripts.dest))
    .pipe(notify({ message: 'Scripts task complete' }));

});

// The task that compiles the Sass
gulp.task('sass', function () {

  // Taking the path from the above object
  return gulp.src(paths.styles.files)

    // Enable support for Sass globbling (*.**)
    .pipe(sassGlob())

    // Initiial the source mapping
    .pipe(sourcemaps.init())

    // Compile the Sass
    .pipe(sass({
      outputStyle: env == 'development' ? 'expanded' : 'compressed',
      sourceComments: 'map',
      includePaths : [paths.styles.src]
    }))
      .on('error', function(err) {
        // If there is an error, don't stop compiling but use the custom displayError function
        displayError(err);
      })

    // Pass the compiled sass through the prefixer with defined
    .pipe(prefix(
      'last 2 version', 'safari 5', 'ie 8', 'ie 9', 'opera 12.1', 'ios 6', 'android 4'
    ))

    // Write the source map
    .pipe(sourcemaps.write('.'))

    // Finally put the compiled sass into a css file
    .pipe(gulp.dest(paths.styles.dest))
});

gulp.task('watch', function() {

  gulp.watch(paths.styles.files, gulp.series('sass'));
  gulp.watch(paths.scripts.files, gulp.series('scripts'));
  gulp.watch(paths.vendorscripts.files, gulp.series('vendorscripts'));

});

// This is the default task - which is run when `gulp` is run
// The tasks passed in as an array are run before the tasks within the function
// gulp.task('default', ['sass', 'vendorscripts', 'scripts'], function() {
//
//   // Watch the files in the paths object, and when there is a change, fun the functions in the array
//   gulp.watch(paths.styles.files, ['sass']);
//   gulp.watch(paths.vendorscripts.files, ['vendorscripts']);
//   gulp.watch(paths.scripts.files, ['scripts']);
//
//     // Also when there is a change, display what file was changed, only showing the path after the 'sass folder'
//     // .on('change', function(evt) {
//     //   console.log(
//     //     '[watcher] File ' + evt.path.replace(/.*(?=sass)/,'') + ' was ' + evt.type + ', compiling...'
//     //   );
//     // });
// });
