<?php
/**
 * Template Name: Calendar Template
 */
?>
<?php get_header(); ?>

<div id="main" class="page-calendar">

  <?php if (have_posts()) : while (have_posts()) : the_post(); ?>
    <?php
    if (get_field('hero_image')) {
      if (get_field('hero_image_parallax')) {
        get_template_part('partials/header-image-parallax');
      }
      else {
        get_template_part('partials/header-image');
      }
    }
    ?>
  <div id="content" class="container-fluid max-width">

    <div class="content-container">

      <?php if (!get_field('hide_title')): ?><h1><?php the_title(); ?></h1><?php endif; ?>

      <div class="content">
        <?php the_field('content'); ?>
      </div>

    </div>
  </div>

  <div class="calendar container-fluid max-width">
    <?php
    $req_date = !empty($_GET['date']) ? $_GET['date'] : date('Ym');
    $date_start = DateTime::createFromFormat('Ym', $req_date);

    if (!$date_start) {
      $date_start = new DateTime('first day of this month');
    }
    else {
      $date_start->modify('first day of this month');
    }
    $date_end = clone $date_start;
    $date_end->modify('last day of this month');

    $date_prev = clone $date_start;
    $date_prev->modify('first day of last month');
    $date_next = clone $date_start;
    $date_next->modify('first day of next month');

    $the_query = new WP_Query(array(
      'post_type' => 'event',
      'posts_per_page' => -1,
      'meta_key' => 'date_start',
      'orderby' => 'meta_value',
      'order' => 'ASC',
      'meta_query' => array(
        'relation' => 'OR',
        array(
          'relation' => 'AND',
          array(
            'key' => 'date_start',
            'value' => $date_start->format('Ymd'),
            'compare' => '>=',
          ),
          array(
            'key' => 'date_start',
            'value' => $date_end->format('Ymd'),
            'compare' => '<=',
          ),
        ),
        array(
          'relation' => 'AND',
          array(
            'key'   => 'date_end',
            'value'   => $date_start->format('Ymd'),
            'compare'   => '>=',
          ),
          array(
            'key'   => 'date_end',
            'value'   => $date_end->format('Ymd'),
            'compare'   => '<=',
          ),
        ),
      ),
    ));
    ?>
    <table class="table table-striped">
      <tr>
        <th colspan="3" class="text-center">
          <a href="<?= esc_url(get_permalink()); ?>?date=<?= $date_prev->format('Ym'); ?>#content" class="prev"><span class="icon-chevron-thin-left"></span><span class="sr-only">Prev</span></a>
          <div class="text">
            <span class="title">Events in</span><br>
            <span class="date"><?= $date_start->format('F Y'); ?></span>
          </div>
          <a href="<?= esc_url(get_permalink()); ?>?date=<?= $date_next->format('Ym'); ?>#content" class="next"><span class="icon-chevron-thin-right"></span><span class="sr-only">Next</span></a>
        </th>
      </tr>
      <?php if ($the_query->have_posts()): ?>
        <?php while ($the_query->have_posts()): $the_query->the_post(); ?>
          <?php
          $date_start = get_field('date_start', false, false);
          if ($time_start = get_field('date_start_time', false, false)) {
            $date_start .= ' ' . $time_start;
            $date_start = DateTime::createFromFormat('Ymd H:i:s', $date_start);
          }
          else {
            $date_start = DateTime::createFromFormat('Ymd', $date_start);
          }

          if ($date_end = get_field('date_end', false, false)) {
            if ($time_end = get_field('date_end_time', false, false)) {
              $date_end .= ' ' . $time_end;
              $date_end = DateTime::createFromFormat('Ymd H:i:s', $date_end);
            }
            else {
              $date_end = DateTime::createFromFormat('Ymd', $date_end);
            }
            $date = date_range($date_start, $date_end);
          }
          else {
            $date = $date_start->format('D F j, Y');
          }
          ?>
      <tr>
        <td class="hidden-xs">
          <?= $date; ?>
          <?php if (get_field('event_times')): ?>
            <br><?php the_field('event_times'); ?>
          <?php endif; ?>
        </td>
        <td>
          <h3><?php the_title(); ?></h3>
          <p class="visible-xs-block">
            <?= $date; ?>
            <?php if (get_field('event_times')): ?>
              <br><?php the_field('event_times'); ?>
            <?php endif; ?>
          </p>
          <p><?php the_field_except(get_field('content')); ?></p>
          <p><a href="<?= esc_url(get_permalink()); ?>">Read more</a></p>
        </td>
        <td class="hidden-xs">
          <form method="post" action="<?= get_template_directory_uri(); ?>/scripts/download-ics.php">
            <input type="hidden" name="date_start" value="<?= $date_start->format('Y-m-d H:i:s'); ?>">
            <?php if ($date_end): ?>
            <input type="hidden" name="date_end" value="<?= $date_end->format('Y-m-d H:i:s'); ?>">
            <?php endif; ?>
            <input type="hidden" name="summary" value="<?php the_title(); ?>">
            <button type="submit"><span class="icon-calendar"></span><span class="sr-only">Add to calendar</span></button>
          </form>
        </td>
      </tr>
        <?php endwhile; ?>
        <?php
        /* Restore original Post Data
         * NB: Because we are using new WP_Query we aren't stomping on the
         * original $wp_query and it does not need to be reset with
         * wp_reset_query(). We just need to set the post data back up with
         * wp_reset_postdata().
         */
        wp_reset_postdata(); ?>

      <?php else: ?>
        <tr>
          <td colspan="3"><p>There are no events scheduled for this month.</p></td>
        </tr>
      <?php endif; ?>
    </table>
  </div>

  <?php endwhile; endif; ?>

</div>

<?php get_footer(); ?>
