<?php
/**
 * Define the ACF load and save points for JSON fields
 */
add_filter('acf/settings/save_json', function() {
  return get_stylesheet_directory() . '/acf-json';
});
add_filter('acf/settings/load_json', function() {
  $paths = array(get_stylesheet_directory() . '/acf-json');
  return $paths;
});

/**
 * Exclude some ACF fields from Yoast
 */
add_filter('ysacf_exclude_fields', function(){
  return array(
    'acf_fc_layout', // This excludes ACF field labels
    'columns',
    'has_bg',
  );
});

/**
 * Define the ACF options pages
 */
if (function_exists('acf_add_options_page')) {
  acf_add_options_page(array(
    'page_title'  => 'Theme General Settings',
    'menu_title'  => 'Theme Settings',
    'menu_slug'   => 'theme-general-settings',
    'capability'  => 'edit_posts',
    'redirect'    => false
  ));
  acf_add_options_sub_page(array(
    'page_title'  => 'Company Details',
    'menu_title'  => 'Company Details',
    'parent_slug' => 'theme-general-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'  => 'Footer Settings',
    'menu_title'  => 'Footer',
    'parent_slug' => 'theme-general-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'  => 'Google Maps Settings',
    'menu_title'  => 'Google Maps',
    'parent_slug' => 'theme-general-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'  => 'Social Settings',
    'menu_title'  => 'Social',
    'parent_slug' => 'theme-general-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'  => 'Widgets',
    'menu_title'  => 'Widgets',
    'parent_slug' => 'theme-general-settings',
  ));
}

/**
 * Create a filter to use our custom image field as the Wordpress featured
 * image so that Yoast will pick it up as the default image for social sharing.
 *
 * acf/update_value/name={$field_name}
 */
add_filter('acf/update_value/name=featured_image', 'acf_set_featured_image', 10, 3);
add_filter('acf/update_value/name=hero_image', 'acf_set_featured_image', 10, 3);
function acf_set_featured_image($value, $post_id, $field) {
  if ($value) {
    add_post_meta($post_id, '_thumbnail_id', $value);
  }
  return $value;
}



function get_field_excerpt($string, $num_words = 20) {
  $return = $string;
  $string = preg_replace('/(?<=\S,)(?=\S)/', ' ', $string);
  $string = str_replace("\n", " ", $string);
  $array = explode(" ", $string);
  if (count($array) <= $num_words) {
    $return = $string;
  }
  else {
    array_splice($array, $num_words);
    $return = implode(" ", $array) . " ...";
  }
  return $return;
}

function the_field_except($string, $num_words = 20) {
  print get_field_excerpt($string, $num_words);
}
