<?php
/**
 * A collection of helper functions.
 */

/**
 * Returns a formatted date range.
 * @param  dateTime $date_start The start date.
 * @param  dateTime $date_end   The end date.
 * @param  string   $format     The PHP date format to use.
 * @return string               The formatted date.
 */
function date_range($date_start, $date_end) {

  if ($date_start->format('Y') != $date_end->format('Y')) {
    return $date_start->format('F j Y') . ' - ' . $date_end->format('F j Y');
  }
  elseif ($date_start->format('M') != $date_end->format('M')) {
    return $date_start->format('j F') . ' - ' . $date_end->format('j F Y');
  }
  elseif ($date_start->format('D') != $date_end->format('D')) {
    return $date_start->format('j') . ' - ' . $date_end->format('j F Y');
  }
  else {
    return $date_start->format('F j Y');
  }

}

function custom_pagination($num_pages = '', $page_range = '', $paged = '') {

  if (empty($page_range)) {
    $page_range = 2;
  }

  /**
   * This first part of our function is a fallback
   * for custom pagination inside a regular loop that
   * uses the global $paged and global $wp_query variables.
   *
   * It's good because we can now override default pagination
   * in our theme, and use this function in default quries
   * and custom queries.
   */
  global $paged;
  if (empty($paged)) {
    $paged = 1;
  }
  if ($num_pages == '') {
    global $wp_query;
    $num_pages = $wp_query->max_num_pages;
    if(!$num_pages) {
        $num_pages = 1;
    }
  }

  /**
   * We construct the pagination arguments to enter into our paginate_links
   * function.
   */
  $pagination_args = array(
    'base'            => get_pagenum_link(1) . '%_%',
    'format'          => 'page/%#%',
    'total'           => $num_pages,
    'current'         => $paged,
    'show_all'        => False,
    'end_size'        => 1,
    'mid_size'        => $page_range,
    'prev_next'       => true,
    'prev_text'       => __('Previous'),
    'next_text'       => __('Next'),
    'type'            => 'plain',
    'add_args'        => false,
    'add_fragment'    => '',
    'before_page_number' => '<span class="meta-nav screen-reader-text">Page </span>',
  );

  $paginate_links = paginate_links($pagination_args);

  if ($paginate_links) {
    $return = array();

    $return[] = '<nav class="pagination custom-pagination">';
    $return[] = '<h2 class="screen-reader-text">Posts navigation</h2>';
    $return[] = '<div class="nav-links">';
    $return[] = $paginate_links;
    $return[] = '</div>';
    $return[] = '</nav>';

    print implode("\n", $return);
  }

}
